==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/DuplicateruleCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Duplicaterule;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.DuplicateruleRequest;
import microsoft.dynamics.crm.entity.request.DuplicateruleconditionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class DuplicateruleCollectionRequest extends CollectionPageEntityRequest<Duplicaterule, DuplicateruleRequest>{

    protected ContextPath contextPath;

    public DuplicateruleCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Duplicaterule.class, cp -> new DuplicateruleRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest duplicateRule_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("DuplicateRule_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest duplicateRule_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("DuplicateRule_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicateruleconditionCollectionRequest duplicateRule_DuplicateRuleConditions() {
        return new DuplicateruleconditionCollectionRequest(contextPath.addSegment("DuplicateRule_DuplicateRuleConditions"), Optional.empty());
    }

    public DuplicateruleconditionRequest duplicateRule_DuplicateRuleConditions(String duplicateruleconditionid) {
        return new DuplicateruleconditionRequest(contextPath.addSegment("DuplicateRule_DuplicateRuleConditions").addKeys(new NameValue(duplicateruleconditionid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest duplicateRule_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("DuplicateRule_Annotation"), Optional.empty());
    }

    public AnnotationRequest duplicateRule_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("DuplicateRule_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest duplicateRule_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("DuplicateRule_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest duplicateRule_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("DuplicateRule_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/DuplicateruleCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Duplicaterule;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.DuplicateruleRequest;
import microsoft.dynamics.crm.entity.request.DuplicateruleconditionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class DuplicateruleCollectionRequest extends CollectionPageEntityRequest<Duplicaterule, DuplicateruleRequest>{

    protected ContextPath contextPath;

    public DuplicateruleCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Duplicaterule.class, cp -> new DuplicateruleRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest duplicateRule_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("DuplicateRule_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest duplicateRule_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("DuplicateRule_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicateruleconditionCollectionRequest duplicateRule_DuplicateRuleConditions() {
        return new DuplicateruleconditionCollectionRequest(contextPath.addSegment("DuplicateRule_DuplicateRuleConditions"), Optional.empty());
    }

    public DuplicateruleconditionRequest duplicateRule_DuplicateRuleConditions(String duplicateruleconditionid) {
        return new DuplicateruleconditionRequest(contextPath.addSegment("DuplicateRule_DuplicateRuleConditions").addKeys(new NameValue(duplicateruleconditionid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest duplicateRule_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("DuplicateRule_Annotation"), Optional.empty());
    }

    public AnnotationRequest duplicateRule_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("DuplicateRule_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest duplicateRule_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("DuplicateRule_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest duplicateRule_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("DuplicateRule_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}
